@@ -19,8 +19,18 @@ with config_file_path.open(mode="rb") as file_processor:
 
 
 # Settings taken from the environment if available.
-APP_DEBUGGING = os.environ.get("WPLA_DEBUG", "False").lower() in ("true", "1", "y", "yes")
-APP_DEPLOYED = os.environ.get("WPLA_DEPLOYED", "False").lower() in ("true", "1", "y", "yes")
+APP_DEBUGGING = os.environ.get("WPLA_DEBUG", "False").lower() in (
+    "true",
+    "1",
+    "y",
+    "yes",
+)
+APP_DEPLOYED = os.environ.get("WPLA_DEPLOYED", "False").lower() in (
+    "true",
+    "1",
+    "y",
+    "yes",
+)
 APP_STORAGE_FOLDER = os.environ.get("WPLA_STORAGE_FOLDER", f"{tempfile.gettempdir()}/Weather_Repository")
 APP_LOG_LEVEL = os.environ.get("WPLA_LOG_LEVEL", APP_CONFIG["logging"]["log_level"]).upper()
 APP_SERVER = os.environ.get("WPLA_SERVER_URL", "http://127.0.0.1:8080")  # 127.0.0.1:8080 for debugging is the default
