@@ -4,8 +4,8 @@
 #  SPDX-FileCopyrightText: 2019-2022 Alliander N.V.
 #  SPDX-License-Identifier: MPL-2.0
 
-"""CDS - ERA5 Single Levels Weather data Model
-"""
+"""CDS - ERA5 Single Levels Weather data Model"""
+
 import copy
 from datetime import datetime
 from typing import List, Optional
@@ -60,7 +60,7 @@ class ERA5SLModel(WeatherModelBase):
 
         # Human output conversion:
         self.to_human = copy.deepcopy(self.to_si)
-        self.to_human["sea_surface_temperature"]["convert"] = self.kelvin_to_celsius
+        # self.to_human["sea_surface_temperature"]["convert"] = self.kelvin_to_celsius
         self.to_human["soil_temperature_level_1"]["convert"] = self.kelvin_to_celsius
         self.to_human["soil_temperature_level_2"]["convert"] = self.kelvin_to_celsius
         self.to_human["soil_temperature_level_3"]["convert"] = self.kelvin_to_celsius
