@@ -49,8 +49,8 @@ class HarmonieAromeRepository(WeatherRepositoryBase):
         self.file_prefix = "AROME"
         self.runtime_limit = 60 * 60 * 3  # 3 hours maximum runtime
         self.permanent_suffixes = ["0000", "0600", "1200", "1800"]
-        self.dataset_name = "harmonie_arome_cy40_p1"
-        self.dataset_version = "0.2"
+        self.dataset_name = "harmonie_arome_cy43_p1"
+        self.dataset_version = "1.0"
         self.file_identifier_length = 13
         self.time_encoding = "hours since 2018-01-01"  # Used to keep values usable for at least the upcoming decennium
 
@@ -126,7 +126,7 @@ class HarmonieAromeRepository(WeatherRepositoryBase):
             if not self._prediction_already_available(prediction_to_evaluate):
                 logger.debug(f"- Gathering the prediction for: {prediction_to_evaluate}")
                 file_to_download = (
-                    f"harm40_v1_p1_{prediction_to_evaluate.year}"
+                    f"HARM43_V1_P1_{prediction_to_evaluate.year}"
                     f"{str(prediction_to_evaluate.month).zfill(2)}"
                     f"{str(prediction_to_evaluate.day).zfill(2)}"
                     f"{str(prediction_to_evaluate.hour).zfill(2)}.tar"
@@ -196,8 +196,7 @@ class HarmonieAromeRepository(WeatherRepositoryBase):
             tar = tarfile.open(download_folder.joinpath(file_name))
             for member in tar.getmembers():
                 if member.isreg():  # Only process files
-                    member.name = os.path.basename(
-                        member.name)  # Remove the path to setting it to only the filename.
+                    member.name = os.path.basename(member.name)  # Remove the path to setting it to only the filename.
                     tar.extract(member, download_folder)  # Extract the file to the download folder
             tar.close()
         except Exception as e:
@@ -207,14 +206,13 @@ class HarmonieAromeRepository(WeatherRepositoryBase):
     def _convert_unpacked_data_to_netcdf4_files(self, download_folder: Path, prediction_time: datetime):
         """This function converts any unpacked data files into NetCDF4 files"""
         try:
-
             logger.debug("Import of cfgrib was successful")
         except RuntimeError as e:
             logger.error("CFGRIB was not properly installed. Cannot access GRIB files.")
             raise e
 
         grib_files_available = glob.glob(
-            str(download_folder.joinpath(f'HA40_N25_{prediction_time.strftime("%Y%m%d%H")}00_*_GB'))
+            str(download_folder.joinpath(f'HA43_N20_{prediction_time.strftime("%Y%m%d%H")}00_*_GB'))
         )
 
         for grib_file in grib_files_available:
@@ -241,7 +239,10 @@ class HarmonieAromeRepository(WeatherRepositoryBase):
             grib_message = item[1]
             # We skip the rotated grid data of the first file in each file-set and only process the regular_ll grids.
             if grib_message["gridType"] == "regular_ll":
-                (field_name, message_dataset,) = self._process_grib_message_to_message_dataset(
+                (
+                    field_name,
+                    message_dataset,
+                ) = self._process_grib_message_to_message_dataset(
                     grib_message=grib_message,
                     prediction_moment=prediction_moment,
                     predicted_hour=predicted_hour,
@@ -375,7 +376,9 @@ class HarmonieAromeRepository(WeatherRepositoryBase):
         fused_dataset.to_netcdf(filename_to_save_to, format="NETCDF4", engine="netcdf4", encoding=encoding)
 
     @staticmethod
-    def _build_lat_lon_grid(grib_message: cfgrib.Message) -> Tuple[List[float], List[float]]:
+    def _build_lat_lon_grid(
+        grib_message: cfgrib.Message,
+    ) -> Tuple[List[float], List[float]]:
         """This function uses an existing GRIB file to extract the dimensions of the 'regular_ll' grid and format
          those into a list of latitudes and a list of longitudes that together make up the grid.
 
