@@ -4,8 +4,8 @@
 #  SPDX-FileCopyrightText: 2019-2022 Alliander N.V.
 #  SPDX-License-Identifier: MPL-2.0
 
-"""KNMI day part prediction data fetcher.
-"""
+"""KNMI day part prediction data fetcher."""
+
 import copy
 from datetime import datetime
 from typing import List, Optional
@@ -15,6 +15,7 @@ import requests
 import xarray as xr
 from dateutil.relativedelta import relativedelta
 from loguru import logger
+from pytz import UTC
 
 from weather_provider_api.routers.weather.base_models.model import WeatherModelBase
 from weather_provider_api.routers.weather.sources.knmi.stations import (
@@ -135,7 +136,7 @@ class PluimModel(WeatherModelBase):
         ds = self._download_weather(coords, coords_stn_ind, stns, weather_factors)
 
         ds = self._select_weather_from_given_period(ds, begin, end)
-        ds = ds.dropna("time", "all")  # Dropping any times that only carry NaN values
+        ds = ds.dropna("time", how="all")  # Dropping any times that only carry NaN values
 
         return ds
 
@@ -157,7 +158,7 @@ class PluimModel(WeatherModelBase):
             datetime.today().replace(hour=0, minute=0, second=0),
             datetime.today().replace(hour=0, minute=0, second=0) + relativedelta(days=15),
         )
-        ds = ds.sel(time=slice(begin, end))
+        ds = ds.sel(time=slice(begin.astimezone(UTC).replace(tzinfo=None), end.astimezone(UTC).replace(tzinfo=None)))
         return ds
 
     def is_async(self):  # pragma: no cover
